==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/UmowaApteka.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class UmowaApteka extends GenericDPSObject {
    /**
     * UMOWA_APTEKA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * UMOWA_APTEKA.DATA_OD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataOd;

    /**
     * UMOWA_APTEKA.DATA_DO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataDo;

    /**
     * UMOWA_APTEKA.KWOTA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwota;

    /**
     * UMOWA_APTEKA.NR
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nr;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return UMOWA_APTEKA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * UMOWA_APTEKA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return UMOWA_APTEKA.DATA_OD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * UMOWA_APTEKA.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return UMOWA_APTEKA.DATA_DO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * UMOWA_APTEKA.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @return UMOWA_APTEKA.KWOTA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * UMOWA_APTEKA.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return UMOWA_APTEKA.NR
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNr() {
        return nr;
    }

    /**
     * UMOWA_APTEKA.NR
     *
     * @param nr
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        UmowaApteka other = (UmowaApteka) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", dataDo=").append(dataDo);
        sb.append(", kwota=").append(kwota);
        sb.append(", nr=").append(nr);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/UmowaApteka.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class UmowaApteka extends GenericDPSObject {
    /**
     * UMOWA_APTEKA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * UMOWA_APTEKA.DATA_OD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataOd;

    /**
     * UMOWA_APTEKA.DATA_DO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataDo;

    /**
     * UMOWA_APTEKA.KWOTA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwota;

    /**
     * UMOWA_APTEKA.NR
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nr;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return UMOWA_APTEKA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * UMOWA_APTEKA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return UMOWA_APTEKA.DATA_OD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * UMOWA_APTEKA.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return UMOWA_APTEKA.DATA_DO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * UMOWA_APTEKA.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @return UMOWA_APTEKA.KWOTA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * UMOWA_APTEKA.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return UMOWA_APTEKA.NR
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNr() {
        return nr;
    }

    /**
     * UMOWA_APTEKA.NR
     *
     * @param nr
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        UmowaApteka other = (UmowaApteka) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", dataDo=").append(dataDo);
        sb.append(", kwota=").append(kwota);
        sb.append(", nr=").append(nr);
        sb.append("]");
        return sb.toString();
    }
}
